package com.android.demo.barcode;

import java.io.UnsupportedEncodingException;
import android.app.Activity;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends Activity implements OnClickListener {

	private static final String TAG = "BarCodeActivity";

	private static final String ACTION_BARCODE_OUTPUTTYPE = "com.barcodeservice.settings.output.type";
	private static final String EXTRA_BARCODE_TYPE = "OUTPUT_TYPE";

	private static final String ACTION_BARCODE = "com.barcodeservice.broadcast.string";
	private static final String EXTRA_BARCODE = "barcodedata";

	private static final String ACTION_START_BCR_ENGINE = "com.barcodeservice.on";
	private static final String ACTION_STOP_BCR_ENGINE = "com.barcodeservice.off";

	private static final String ACTION_TRIGGER_ON =  "com.barcodeservice.start.scan";
	private static final String ACTION_TRIGGER_OFF = "com.barcodeservice.stop.scan";

	private static final String ACTION_HIDE_SOFT_BTN = "com.barcodeservice.settings.virtualbutton.off";
	private static final String ACTION_BEEP_SOUND_OFF = "com.barcodeservice.settings.beepsound.off";

	private static final String ACTION_BARCODE_SCAN_TIMEOUT = "com.barcodeservice.scan.result.timeout";

	private TextView mTxMode;
	private EditText mCmdArea;
	private Button mBtnClear, mBtnSend, mBtnSend2, mBtnSend3;
	private Button mBtnEnable, mBtnDisable;

	BroadcastReceiver mReceiver;

	Application mApp;

	private void initControls() {

		// Edit area
		mCmdArea = (EditText) findViewById(R.id.EditEmission);
		mCmdArea.requestFocus();//auto focus in order to get barcode

		// Buttons
		mBtnEnable = (Button) findViewById(R.id.btnEnable);
		mBtnEnable.setOnClickListener(this);

		mBtnDisable = (Button) findViewById(R.id.btnDisable);
		mBtnDisable.setOnClickListener(this);

		mBtnSend = (Button) findViewById(R.id.btnSend);
		mBtnSend.setOnClickListener(this);

		mBtnSend2 = (Button) findViewById(R.id.btnSend2);
		mBtnSend2.setOnClickListener(this);

		mBtnSend3 = (Button) findViewById(R.id.btnSend3);
		mBtnSend3.setOnClickListener(this);

		mBtnClear = (Button) findViewById(R.id.btnClear);
		mBtnClear.setOnClickListener(this);
	}

	@Override
	public void onCreate(Bundle savedInstanceState) {
		Log.i(TAG, "onCreate()");
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main_tab2);

		mApp = (Application) getApplication();

		initControls();

		mReceiver = new BroadcastReceiver() {

			@Override
			public void onReceive(Context context, Intent intent) {
				if (intent.getAction().equals(ACTION_BARCODE)) {
					String barcode = intent.getStringExtra(EXTRA_BARCODE);

					if(barcode != null) {
						final String str = "BarCode is " + barcode;
						Log.d(TAG, str);
						mCmdArea.append(str);
					}
				} else if (intent.getAction().equals(ACTION_BARCODE_SCAN_TIMEOUT)) {
					Log.d(TAG, "Receive scan timeout event");
				}
			}
		};
	}


	public void triggerON()
	{
		sendBroadcast(new Intent(ACTION_TRIGGER_ON));
	}


	// Start BarCode Service
	public void starBCRService()
	{
		sendBroadcast(new Intent(ACTION_START_BCR_ENGINE));

		//*** Set barcode out mode to broadcast
		// if you want to receive the barcode in broadcast receiver
		setBarCodeOutputMode("1");//"1" FOR BROADCAST MODE
	}

	// Stop BarCode Service
	public void stopBCRService()
	{
		sendBroadcast(new Intent(ACTION_STOP_BCR_ENGINE));
	}

	public void setBarCodeOutputMode(String mode)
	{
		Intent intent = new Intent();
		intent.setAction(ACTION_BARCODE_OUTPUTTYPE);
		intent.putExtra(EXTRA_BARCODE_TYPE, mode);
		sendBroadcast(intent);
	}

	@Override
	public void onResume() {
		Log.i(TAG, "onResume()");
		super.onResume();
		registerReceiver(mReceiver, new IntentFilter(ACTION_BARCODE));
		registerReceiver(mReceiver, new IntentFilter(ACTION_BARCODE_SCAN_TIMEOUT));
	}

	@Override
	public void onPause() {
		Log.i(TAG, "onPause()");
		super.onPause();

		unregisterReceiver(mReceiver);
	}

	@Override
	public void onDestroy() {
		Log.i(TAG, "onDestroy()");

		//*** Set barcode out mode to KEY BOARD MODE
		setBarCodeOutputMode("0");

		// MUST CALL !!!
		super.onDestroy();
	}

	public void onClick(View v) {
		try {
			switch (v.getId()) {
				case R.id.btnEnable://Enable Barcode service
					starBCRService();
					break;

				case R.id.btnSend://Trigger ON
					triggerON();
					break;

				case R.id.btnSend2://Hide Soft btn
					sendBroadcast(new Intent(ACTION_HIDE_SOFT_BTN));
					break;

				case R.id.btnSend3:
					sendBroadcast(new Intent(ACTION_BEEP_SOUND_OFF));
					break;

				case R.id.btnDisable://Disable Barcode service
					stopBCRService();
					break;

				case R.id.btnClear:
					mCmdArea.setText("");
					break;

			}
		} catch (Exception e) {
			Log.d(TAG, "onClick() exception: " + e.getMessage());
		}
	}

	protected void toastMsg(String msg) {
		Toast.makeText(this, msg, Toast.LENGTH_SHORT).show();
	}

	protected void toastMsg(int resId) {
		String msg = getResources().getString(resId);
		Toast.makeText(this, msg, Toast.LENGTH_SHORT).show();
	}


}
